@@ -1,5 +1,4 @@
 import socket
-import json
 import pickle
 import threading
 from .utils import *
@@ -47,7 +46,7 @@ class SS(object):
                     )
                 elif request["command"] in self.functions:
                     try:
-                        response = self.functions[request["command"]](request["data"])
+                        response = self.functions[request["command"]](*request["data"][0], **request["data"][1])
                     except:
                         response = debug_info()
                 try:
@@ -60,7 +59,9 @@ class SS(object):
                 conn.sendall(response)
                 if request["command"] == "set_key":
                     try:
-                        bkey = self.rsad(b64d(request["data"]))
+                        bkey = b""
+                        for part in request["data"][0]:
+                            bkey += self.rsad(b64d(part))
                     except:
                         raise Exception("current connection is under MITM attack")
                     self.__key[uid] = bkey
